#!/bin/bash
#written via TheeMahn
VERSION='1.04'

echo "Ultimate Edition Conky builder version "$VERSION
echo "Please report errors / issues to TheeMahn <TheeMahn@ultimateedition.info>"
echo "========================================================================="
OS='Ultimate Edition'

#Detect codebase
CODEBASE=`cat /etc/lsb-release | grep 'DISTRIB_CODENAME=' | sed 's/DISTRIB_CODENAME=//g'`

echo "Codebase detected: "$CODEBASE

# detect if release is odd or even.
EVENODD=`dpkg -l | grep kubuntu-desktop`

	if [[ $EVENODD != "" ]]; then
		echo "Kubuntu base: detected - odd number release"
	else
		echo "Kubuntu base not detected - even number release"
	fi


echo -n "Distro detected: "
case "$CODEBASE" in
    natty) 
	if [[ $EVENODD != "" ]]; then
		OS=$OS" 3.1"
	else
		OS=$OS" 3.0"
	fi
	echo $OS ;;
    maverick) 
	if [[ $EVENODD != "" ]]; then
		OS=$OS" 2.9"
	else
		OS=$OS" 2.8"
	fi
	echo $OS ;;
    lucid) 
	if [[ $EVENODD != "" ]]; then
		OS=$OS" 2.7"
	else
		OS=$OS" 2.6.3"
	fi
	echo $OS ;;

    *)  echo "Unknown O/S using $CODEBASE"
esac


# Attempt to advance the script.  No sense having the user edit this script if we can obtain the information.

res=`xrandr -q | grep 'current' | cut -d"," -f2 | sed 's/current//g' | sed 's/ //g'`

# set default in case user has an unknown resolution.
GRAPHWIDTH=320 #size of box in pixels
FONTSIZE=12

echo "Detected current resolution:" $res

case "$res" in
    1920x1200)
	GRAPHWIDTH=400
	FONTSIZE=14
	echo "Setting Font size to 14 and graph width to 480" ;;
    1920X1080)
	GRAPHWIDTH=400
	FONTSIZE=14
	echo "Setting Font size to 14 and graph width to 400" ;;
    1680x1050)
	GRAPHWIDTH=320
	FONTSIZE=12
	echo "Setting Font size to 14 and graph width to 320" ;;
    1440x900)
	GRAPHWIDTH=310
	FONTSIZE=12
	echo "Setting Font size to 12 and graph width to 310" ;;
    1400x1050)
	GRAPHWIDTH=310
	FONTSIZE=12
	echo "Setting Font size to 12 and graph width to 280" ;;
    1280x1024)
	GRAPHWIDTH=310
	FONTSIZE=12
	echo "Setting Font size to 12 and graph width to 310" ;;
    1280x960)
	GRAPHWIDTH=300
	FONTSIZE=12
	echo "Setting Font size to 12 and graph width to 300" ;;
    1152x864)
	GRAPHWIDTH=240
	FONTSIZE=9
	echo "Setting Font size to 9 and graph width to 240" ;;
    1024x768)
	GRAPHWIDTH=240
	FONTSIZE=9
	echo "Setting Font size to 9 and graph width to 240" ;;
    832x624)
	GRAPHWIDTH=220
	FONTSIZE=8
	echo "Setting Font size to 8 and graph width to 220" ;;
    720x400)
	GRAPHWIDTH=180
	FONTSIZE=6
	echo "Setting Font size to 6 and graph width to 180" ;;
    640x480)
	GRAPHWIDTH=180
	FONTSIZE=6
	echo "Setting Font size to 6 and graph width to 180" ;;
    *)  
	GRAPHWIDTH=320
	FONTSIZE=12
	echo "Resolution unprogramed defaulting, please report detected resolution above to <theemahn@ultimateedition.info>" ;;
esac

#set Base, hilight color & header please adjust colors in hex and font to your liking
BASE='${color #ffffff}${font Liberation Liberation:style=normal:pixelsize='$FONTSIZE'}'
HILIGHT='${color #00ff00}${font Liberation Liberation:style=normal:pixelsize='$FONTSIZE'}'
HEADER='${color #ffff00}${font Liberation:style=Bold:pixelsize='$FONTSIZE'}'
BAR='${color #ff0000}'

############### You Should not have to edit anything below #############

#Calculate v offset based on Fonts / pixelsize
VOFF=$((FONTSIZE+6))
ALEFT=$((FONTSIZE/4))
INDENT=$((FONTSIZE/3))
BARZ=$((GRAPHWIDTH/2))
BOFFSET=$((FONTSIZE/2))
TICON=$((FONTSIZE/5))
BPER=$((GRAPHWIDTH/100*75))
SBAR=$((GRAPHWIDTH/100*20))
LOGO=$((FONTSIZE*4))

#Get CPU model
PROC=`cat /proc/cpuinfo | grep 'model name' | sed -e 's/.*: //' | uniq`
echo "Detected Processor:" $PROC

#check Architecture set 32 bit default
ARCHITECTURE='32 Bit'

#
# Check for x86_64 (Test 1) - some O/S's use the -i switch
#
if [ "`uname -i|grep x86_64`" == "x86_64" ]; then
	ARCHITECTURE='64 Bit'
fi

#
# Check for x86_64 (Test 2) - some OSs (ie. Gentoo) return Processor manufacturer
# 	rather than architecture with "uname -i"
#
if [ "`uname -a|grep x86_64`" != "" ]; then
	ARCHITECTURE='64 Bit'
fi


echo $ARCHITECTURE 'O/S detected.'

#Create conky skelaton
echo '#Use XFT?
use_xft yes
xftfont Liberation Sans:size=10
xftalpha 0.8
text_buffer_size 2048

# Update interval in seconds
update_interval 1

# This is the number of times Conky will update before quitting.
# Set to zero to run forever.
total_run_times 0

# Create own window instead of using desktop (required in nautilus)
own_window yes
own_window_transparent yes
own_window_type override
#own_window_hints undecorated,below,sticky,skip_taskbar,skip_pager

# Use double buffering (reduces flicker, may not work for everyone)
double_buffer yes

# Minimum size of text area -adjust if you would like to user smaller fonts etc.
minimum_size '$GRAPHWIDTH' 0
maximum_width '$GRAPHWIDTH'

# Draw shades?
draw_shades no
default_color 00ff00 #000000
# Draw outlines?
draw_outline no

# Draw borders around text
draw_borders no

# Stippled borders?
stippled_borders 0

# border margins
border_margin 5

# border width
border_width 1

# Text alignment, other possible values are commented
#alignment top_left
alignment top_right
#alignment bottom_left
#alignment bottom_right

# Gap between borders of screen and text
# same thing as passing -x at command line
gap_x 15
gap_y 45

# -- Lua Load -- #
lua_load ~/.draw_bg.lua
lua_draw_hook_pre draw_bg

' > ~/.conkyrc

#Count number of processor cores
CORES=1
CORES=`cat /proc/cpuinfo | grep "processor" | wc -l`
echo $CORES "Cpu core(s) Detected."
echo 'TEXT
${goto '$INDENT'}${image /usr/share/ultimate_edition/logo.png -p '$BARZ','$LOGO' -s 32x32}'$HEADER'SYSTEM ${hr 2 }
'$HILIGHT'${alignr}'$OS' - $alignr$kernel '$ARCHITECTURE'
'$HILIGHT'${alignr}'$USER'@$nodename
'$BASE'${goto '$INDENT'}${voffset '$TICON'}${font StyleBats:pixelsize='$FONTSIZE'}k${font}${voffset -'$ALEFT'}${goto '$VOFF'}'$BASE'Processes: ${alignr}'$HILIGHT'$processes ($running_processes running)
'$BASE'${goto '$INDENT'}${voffset '$TICON'}${font StyleBats:pixelsize='$FONTSIZE'}q${font}${voffset -'$ALEFT'}${goto '$VOFF'}'$BASE'Uptime: '$HILIGHT'${alignr}${uptime}
'$HILIGHT'${goto '$INDENT'}${voffset '$TICON'}${font Stylebats:pixelsize='$FONTSIZE'}A${font}${voffset -'$ALEFT'}${goto '$VOFF'}'$HEADER'${goto '$VOFF'}CPU${hr 1 }
'$HILIGHT$PROC'
${goto '$INDENT'}${font StyleBats:pixelsize='$FONTSIZE'}A${font}${voffset -'$ALEFT'}${goto '$VOFF'}'$BASE'CPU Usage: '$HILIGHT' ${freq}MHz X '$CORES'${alignr}${cpu cpu0}% '$BAR' ${cpubar cpu0 '$INDENT','$SBAR'}
'$BASE'Cores: ${hr 1 }' >> ~/.conkyrc

#Create a cpubar for each core
COUNTER=0
         while [  $COUNTER != $CORES ]; do
		let COUNTER=COUNTER+1 
		echo '${goto '$INDENT'}${voffset '$TICON'}${font StyleBats:pixelsize='$FONTSIZE'}A${font}${voffset -'$ALEFT'}${goto '$VOFF'}'$BASE'Core '$COUNTER':' $HILIGHT'${cpu cpu'$COUNTER'}% '$BAR'${alignr}${cpubar cpu'$COUNTER' '$INDENT','$BPER'}'$BASE >> ~/.conkyrc
         done

#Output disk I/O bar top processes memory useage etc.
echo $HILIGHT'${goto '$INDENT'}${voffset '$TICON'}${font Stylebats:pixelsize='$FONTSIZE'}g${font}${voffset -'$ALEFT'}${goto '$VOFF'}'$HEADER'${goto '$VOFF'}RAM${hr 1 }'$BASE'
Useage: '$HILIGHT'$mem / $memmax ${alignr}'$HILIGHT'$memperc% '$BAR'${membar '$INDENT','$SBAR'}'$BASE'
'$BASE'${goto '$INDENT'}${voffset '$TICON'}${font Stylebats:pixelsize='$FONTSIZE'}j${font}${voffset -'$ALEFT'}${goto '$VOFF'}'$BASE'Swap: '$HILIGHT'$swap/$swapmax${alignr}$swapperc% '$BAR'${swapbar '$INDENT','$SBAR'}
'$HILIGHT'${goto '$INDENT'}${voffset '$TICON'}${font Poky:pixelsize='$FONTSIZE'}d${font}${voffset -'$ALEFT'}${goto '$VOFF'}'$HEADER'${goto '$VOFF'}${alignc}${time %H:%M}, ${time %A %d %B}
'$HILIGHT'${goto '$INDENT'}${voffset '$TICON'}${font Poky:pixelsize='$FONTSIZE'}a${font}${voffset -'$ALEFT'}${goto '$VOFF'}'$HEADER'${goto '$VOFF'}Highest: ${alignr}CPU RAM
${goto '$VOFF'}${voffset -5.5}${hr 1}
'$HILIGHT'${voffset -1}${goto '$VOFF'}${top name 1}${alignr}${top cpu 1}  ${top mem 1}
${goto '$VOFF'}${top name 2}${alignr}${top cpu 2}  ${top mem 2}
${goto '$VOFF'}${top name 3}${alignr}${top cpu 3}  ${top mem 3}
${goto '$VOFF'}${top name 4}${alignr}${top cpu 4}  ${top mem 4}
'$HILIGHT'${goto '$INDENT'}${voffset '$TICON'}${font Poky:pixelsize='$FONTSIZE'}H${font}${voffset -'$ALEFT'}${goto '$VOFF'}'$HEADER'${goto '$VOFF'}FILESYSTEM${hr 1 }'$BASE'
'$BASE'${goto '$INDENT'}${voffset '$TICON'}${font Poky:pixelsize='$FONTSIZE'}Y${font}${voffset -'$ALEFT'}${goto '$VOFF'}'$BASE'Disk I/O: '$HILIGHT'${diskio}${alignr}'$BAR'${diskiograph 20,'$BARZ'}
'$BASE'${goto '$INDENT'}${voffset '$TICON'}${font Poky:pixelsize='$FONTSIZE'}H${font}${voffset -'$ALEFT'}${goto '$VOFF'}'$BASE'Root: '$HILIGHT'${fs_free /} / ${fs_size /}${alignr}${fs_used_perc /}% '$BAR'${fs_bar '$INDENT','$SBAR' /}'$BASE >> ~/.conkyrc

#Detect hard disks & create a bar for each mount point
echo "Internal / External storage detected:"
echo "/ - Root" 
ls /media/ > /tmp/tmp.txt
cat /tmp/tmp.txt | while read FILE
do
target=$(echo "$FILE" | sed -e "s/ /_/")
echo ''$BASE'${goto '$INDENT'}${voffset '$TICON'}${font Poky:pixelsize='$FONTSIZE'}H${font}${voffset -'$ALEFT'}${goto '$VOFF'}'$BASE$FILE': '$HILIGHT'${fs_free /media/'$FILE'} / ${fs_size /media/'$FILE'}${alignr}${fs_used_perc /media/'$FILE'}% '$BAR'${fs_bar '$INDENT','$SBAR' /media/'$FILE'}'$BASE >> ~/.conkyrc
echo $FILE
done
rm /tmp/tmp.txt
echo $HILIGHT'${goto '$INDENT'}${voffset '$TICON'}${font Stylebats:pixelsize='$FONTSIZE'}5${font}${voffset -'$ALEFT'}${goto '$VOFF'}'$HEADER'${goto '$VOFF'}NETWORK${hr 1}' >> ~/.conkyrc


#Detect "Active" network and propigate Network Xfer bar
ACTIVE=`ifconfig | grep -B 1 inet | head -1 | awk '{print $1}'`
echo $BASE'${voffset 2}${font VariShapes Solid:pixelsize='$FONTSIZE'}q${font}${goto '$VOFF'}${voffset -'$ALEFT'}${font}'$BASE'Up: ${upspeed '$ACTIVE'} '$BAR'${alignr}${upspeedgraph '$ACTIVE' 20,'$BARZ' '$BASE' '$BAR' }
'$BASE'${voffset -24}${goto '$VOFF'}Total: ${totalup '$ACTIVE'}
${voffset -'$ALEFT'}${font VariShapes Solid:pixelsize='$FONTSIZE'}Q${font}${goto '$VOFF'}${voffset -'$ALEFT'}'$BASE'Down: ${downspeed '$ACTIVE'}${font} '$BAR'${alignr}${downspeedgraph '$ACTIVE' 20,'$BARZ' '$BASE' '$BAR'}
'$BASE'${voffset -24}${goto '$VOFF'}Total: ${totaldown '$ACTIVE'}
${voffset -'$ALEFT'}${font Poky:pixelsize='$FONTSIZE'}w${font}${goto '$VOFF'}${voffset -'$ALEFT'}'$BASE'Local IP: '$HILIGHT'${alignr}${addr '$ACTIVE'}
'$BASE'TCP Connections: '$HILIGHT'${tcp_portmon 1 65535 count}
' >> ~/.conkyrc
echo $HEADER'${voffset -'$ALEFT'}${hr 2}
' >> ~/.conkyrc
